@@ -8,16 +8,12 @@
 #include <KAboutData>
 #include <KDBusService>
 #include <KLocalizedString>
-#include <QApplication>
+#include <QGuiApplication>
 #include <QCommandLineParser>
 
 int main(int argc, char **argv)
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    QCoreApplication::setAttribute(Qt::AA_EnableHighDpiScaling, true);
-    QCoreApplication::setAttribute(Qt::AA_UseHighDpiPixmaps, true);
-#endif
-    QApplication app(argc, argv);
+    QGuiApplication app(argc, argv);
 
     KAboutData aboutData {QStringLiteral("kongressac"), i18n("Kongress Alarm Check Daemon"),
                           QString {}, i18n("Kongress Alarm Check Daemon"),
